@@ -18,6 +18,10 @@ double lin_cost_worker(const NumericVector &x, const NumericVector &y,
   if(j <= (i + (min_seg-1))) {
     return std::numeric_limits<double>::max();
   }
+  const int vlen = x.length();
+  if((i<0) || (j>=vlen) || (vlen!=y.length()) || (vlen!=w.length()) || (min_seg<1)) {
+    throw std::range_error("Inadmissible value");
+  }
   NumericVector fits = xlin_fits_worker(x, y, w, i, j);
   double sum_loss = 0.0;
   for(int k=i; k<=j; ++k) {
@@ -37,7 +41,7 @@ double lin_cost_worker(const NumericVector &x, const NumericVector &y,
 //' @param x NumericVector, x-coords of values to group.
 //' @param y NumericVector, values to group in order.
 //' @param w NumericVector, weights.
-//' @param min_seg positive integer, minimum segment size.
+//' @param min_seg positive integer, minimum segment size (>=1).
 //' @param i integer, first index (inclusive).
 //' @param j integer, j>=i last index (inclusive);
 //' @return scalar, linear cost of [i,...,j] interval (inclusive).
@@ -64,7 +68,7 @@ double lin_cost(NumericVector x, NumericVector y, NumericVector w,
 //' @param x NumericVector, x-coords of values to group.
 //' @param y NumericVector, values to group in order.
 //' @param w NumericVector, weights.
-//' @param min_seg positive integer, minimum segment size.
+//' @param min_seg positive integer, minimum segment size (>=1).
 //' @param indices IntegerVector, ordered list of indices to pair.
 //' @return xcosts NumericMatix, for j>=i xcosts(i,j) is the cost of partition element [i,...,j] (inclusive).
 //' 
@@ -77,6 +81,10 @@ double lin_cost(NumericVector x, NumericVector y, NumericVector w,
 NumericMatrix lin_costs(NumericVector x, NumericVector y, NumericVector w,
                         const int min_seg,
                         IntegerVector indices) {
+  const int vlen = x.length();
+  if((vlen!=y.length()) || (vlen!=w.length()) || (min_seg<1)) {
+    throw std::range_error("Inadmissible value");
+  }
   const int n = indices.size();
   NumericMatrix xcosts = NumericMatrix(n, n);
   const double single_value = std::numeric_limits<double>::max();
